package com.ynet.life.data;

import com.ynet.gene.data.DataElement;
import com.ynet.life.base.LifeStandard;

/* loaded from: com_ynet_life_data.jar:com/ynet/life/data/DataField.class */
public class DataField extends DataElement {
    private Object value;
    private Object defaultValue;
    private String description;
    private String dataType;
    private boolean required;

    public DataField() {
        this.required = false;
    }

    public DataField(String name) {
        super(name);
        this.required = false;
    }

    public DataField(String name, Object value) {
        super(name);
        this.required = false;
        setValue(value);
    }

    public void setDescription(String desc) {
        this.description = desc;
    }

    public void setDefaultValue(Object value) {
        this.defaultValue = value;
    }

    public void setValue(Object value) {
        this.value = value;
    }

    public void setValue(String value) {
        this.value = value;
    }

    public String getDescription() {
        return this.description;
    }

    public Object getDefaultValue() {
        return this.defaultValue;
    }

    public Object getValue() {
        return this.value;
    }

    public void setDataType(String type) {
        this.dataType = type;
    }

    public String getDataType() {
        return this.dataType;
    }

    public Object clone() {
        DataField field = new DataField();
        field.setName(getName());
        field.setValue(this.value);
        field.setDataType(this.dataType);
        field.setAppend(isAppend());
        return field;
    }

    public void reset() {
    }

    public String toString() {
        return toString(0);
    }

    public String toString(int tabCount) {
        StringBuffer buf = new StringBuffer();
        for (int i = 0; i < tabCount; i++) {
            buf.append("\t");
        }
        buf.append("<field id=\"");
        buf.append(getName());
        String bankSettingsValue = LifeStandard.getBankSettingsValue("PasswordFields_Masked");
        String passStr = bankSettingsValue;
        if (!bankSettingsValue.startsWith(",")) {
            passStr = String.valueOf(passStr) + ",";
        }
        if (this.value != null) {
            String tempValue = this.value.toString();
            try {
                if (passStr.indexOf("," + getName() + ",") != -1) {
                    tempValue = "******";
                }
            } catch (Exception unused) {
            }
            buf.append("\" value=\"");
            buf.append(formatXML(tempValue));
        }
        if (this.dataType != null) {
            buf.append("\" dataType=\"");
            buf.append(this.dataType);
        }
        buf.append("\" append=\"" + isAppend() + "\"/>");
        return buf.toString();
    }

    private String formatXML(String str) {
        if (str == null || str.length() == 0) {
            return str;
        }
        return str.replaceAll("\\&", "&amp;").replaceAll("\\'", "&apos;").replaceAll("\\\"", "&quot;").replaceAll("\\<", "&lt;").replaceAll("\\>", "&gt;");
    }

    public boolean isRequired() {
        return this.required;
    }

    public void setRequired(boolean required) {
        this.required = required;
    }

    public String toJSon() {
        StringBuffer buf = new StringBuffer();
        if (this.value != null) {
            String temp = this.value.toString();
            replaceJSonKeyChar(temp, "\\", "\\\\");
            buf.append("\"" + replaceJSonKeyChar(replaceJSonKeyChar(replaceJSonKeyChar(replaceJSonKeyChar(temp, "\"", "\\\""), "\n", "\\n"), "\r", "\\r"), "\t", "\\t") + "\"");
        } else {
            buf.append("null");
        }
        return buf.toString();
    }

    private String replaceJSonKeyChar(String srcStr, String keyStr, String newStr) {
        if (srcStr == null || srcStr.length() == 0) {
            return srcStr;
        }
        if (keyStr == null || newStr == null) {
            return srcStr;
        }
        String temp = "";
        while (srcStr.indexOf(keyStr) != -1) {
            int idx = srcStr.indexOf(keyStr);
            temp = String.valueOf(srcStr.substring(0, idx)) + newStr;
            srcStr = srcStr.substring(idx + keyStr.length());
        }
        return String.valueOf(temp) + srcStr;
    }
}
